- Increased PPD timeout in copy_model() (bug #216065).

- Resolves: rhbz#216065
This commit is contained in:
Tim Waugh 2006-11-22 10:48:21 +00:00
parent 9c61944ee2
commit 18cfbfea32
2 changed files with 25 additions and 0 deletions

View File

@ -0,0 +1,20 @@
--- cups-1.2.7/scheduler/ipp.c.driverd-timeout 2006-11-22 10:41:28.000000000 +0000
+++ cups-1.2.7/scheduler/ipp.c 2006-11-22 10:45:55.000000000 +0000
@@ -4175,7 +4175,7 @@
close(temppipe[1]);
/*
* Wait up to 30 seconds for the PPD file to be copied...
*/
total = 0;
@@ -4196,7 +4196,7 @@
FD_SET(temppipe[0], input);
FD_SET(CGIPipes[0], input);
- timeout.tv_sec = 30;
+ timeout.tv_sec = 70;
timeout.tv_usec = 0;
if ((i = select(maxfd, input, NULL, NULL, &timeout)) < 0)

View File

@ -44,6 +44,7 @@ Patch17: cups-relro.patch
Patch18: cups-directed-broadcast.patch
Patch19: cups-eggcups.patch
Patch20: cups-getpass.patch
Patch21: cups-driverd-timeout.patch
Patch100: cups-lspp.patch
Epoch: 1
Url: http://www.cups.org/
@ -146,6 +147,7 @@ lpd emulation.
%patch18 -p1 -b .directed-broadcast
%patch19 -p1 -b .eggcups
%patch20 -p1 -b .getpass
%patch21 -p1 -b .driverd-timeout
%if %lspp
%patch100 -p1 -b .lspp
@ -428,6 +430,9 @@ rm -rf $RPM_BUILD_ROOT
%{cups_serverbin}/daemon/cups-lpd
%changelog
* Wed Nov 22 2006 Tim Waugh <twaugh@redhat.com>
- Increased PPD timeout in copy_model() (bug #216065).
* Tue Nov 21 2006 Tim Waugh <twaugh@redhat.com> 1:1.2.7-3
- Run the serial backend as root (bug #212577).
@@ -4175,7 +4175,7 @@
close(temppipe[1]);
/*
- * Wait up to 30 seconds for the PPD file to be copied...
+ * Wait up to 70 seconds for the PPD file to be copied...
*/
total = 0;